/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.manager.controller;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import io.jsonwebtoken.Claims;
import io.jsonwebtoken.JwtParser;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import lombok.AllArgsConstructor;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.validation.Valid;

import org.springblade.core.jwt.JwtUtil;
import org.springblade.core.mp.support.Condition;
import org.springblade.core.mp.support.Query;
import org.springblade.core.secure.constant.AuthConstant;
import org.springblade.core.secure.utils.AuthUtil;
import org.springblade.core.tool.api.R;
import org.springblade.core.tool.utils.Func;
import org.springblade.core.tool.utils.ThreadLocalUtil;
import org.springframework.util.AntPathMatcher;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.bind.annotation.RequestParam;

import org.springblade.manager.entity.ContractInfo;
import org.springblade.manager.vo.ContractInfoVO;
import org.springblade.manager.wrapper.ContractInfoWrapper;
import org.springblade.manager.service.IContractInfoService;
import org.springblade.core.boot.ctrl.BladeController;
import springfox.documentation.annotations.ApiIgnore;

import java.sql.Wrapper;
import java.util.*;

/**
 * 合同段信息表 控制器
 *
 * @author liuyc
 * @since 2022-04-14
 */
@RestController
@AllArgsConstructor
@RequestMapping("/contractInfo")
@Api(value = "合同段信息表", tags = "合同段信息表接口")
public class ContractInfoController extends BladeController {

	@Resource
	private final IContractInfoService contractInfoService;


	//测试条件查询
	@GetMapping("/selectAllList")
	public R<List<ContractInfo>> selectAllList(ContractInfo contractInfo){
		List<ContractInfo> list = contractInfoService.list(Wrappers.query(contractInfo));
		return R.data(list);
	}

	//测试分页查询
	@GetMapping("/page2")
	public R<IPage<ContractInfo>> page(@ApiIgnore @RequestParam Map<String, Object> obj, Query query) {
		IPage<ContractInfo> pages = contractInfoService.page(Condition.getPage(query), Condition.getQueryWrapper(obj, ContractInfo.class));
		return R.data(pages);
	}

	/**
	 * 详情
	 */
	@GetMapping("/detail")
	@ApiOperationSupport(order = 1)
	@ApiOperation(value = "详情", notes = "传入contractInfo")
	public R<ContractInfoVO> detail(ContractInfo contractInfo) {
		ContractInfo detail = contractInfoService.getOne(Condition.getQueryWrapper(contractInfo));
		return R.data(ContractInfoWrapper.build().entityVO(detail));
	}

	/**
	 * 根据项目名称查询当前所有合同
	 */
	@GetMapping("/findContractInfoByPid")
	@ApiOperationSupport(order = 8)
	@ApiOperation(value = "合同ID", notes = "传入pid")
	public R<List<ContractInfo>> findContractInfoByPid(String pid){
		List<ContractInfo> contractInfoVOS = contractInfoService.selectContractInfoPageByPid(pid);
		return R.data(contractInfoVOS);
	}

	/**
	 * 分页 合同段信息表
	 */
	@GetMapping("/list")
	@ApiOperationSupport(order = 2)
	@ApiOperation(value = "分页", notes = "传入contractInfo")
	public R<IPage<ContractInfoVO>> list(ContractInfo contractInfo, Query query) {
		IPage<ContractInfo> pages = contractInfoService.page(Condition.getPage(query), Condition.getQueryWrapper(contractInfo));
		return R.data(ContractInfoWrapper.build().pageVO(pages));
	}

	/**
	 * 自定义分页 合同段信息表
	 */
	@GetMapping("/page")
	@ApiOperationSupport(order = 3)
	@ApiOperation(value = "分页", notes = "传入contractInfo")
	public R<IPage<ContractInfoVO>> page(ContractInfoVO contractInfo, Query query){
		IPage<ContractInfoVO> pages = contractInfoService.selectContractInfoPage(Condition.getPage(query), contractInfo);
		//获取token信息
		/*String[] tokens = AuthUtil.getHeader().split(" ");
		if (tokens.length>=1){
			System.out.println(tokens[1]);
			//解析
			Claims claims = JwtUtil.parseJWT(tokens[1]);
			System.out.println(claims);
		}*/
		return R.data(pages);
	}


	/**
	 * 新增 合同段信息表
	 */
	@PostMapping("/save")
	@ApiOperationSupport(order = 4)
	@ApiOperation(value = "新增", notes = "传入contractInfo")
	public R save(@Valid @RequestBody ContractInfo contractInfo) {
		return R.status(contractInfoService.save(contractInfo));
	}

	/**
	 * 修改 合同段信息表
	 */
	@PostMapping("/update")
	@ApiOperationSupport(order = 5)
	@ApiOperation(value = "修改", notes = "传入contractInfo")
	public R update(@Valid @RequestBody ContractInfo contractInfo) {
		return R.status(contractInfoService.updateById(contractInfo));
	}

	/**
	 * 新增或修改 合同段信息表
	 */
	@PostMapping("/submit")
	@ApiOperationSupport(order = 6)
	@ApiOperation(value = "新增或修改", notes = "传入contractInfo")
	public R submit(@Valid @RequestBody ContractInfo contractInfo) {
		return R.status(contractInfoService.saveOrUpdate(contractInfo));
	}


	/**
	 * 删除 合同段信息表
	 */
	@PostMapping("/remove")
	@ApiOperationSupport(order = 7)
	@ApiOperation(value = "逻辑删除", notes = "传入ids")
	public R remove(@ApiParam(value = "主键集合", required = true) @RequestParam String ids) {
		return R.status(contractInfoService.deleteLogic(Func.toLongList(ids)));
	}


}
