/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.manager.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiParam;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import lombok.AllArgsConstructor;
import javax.validation.Valid;

import org.springblade.core.mp.support.Condition;
import org.springblade.core.mp.support.Query;
import org.springblade.core.tool.api.R;
import org.springblade.core.tool.utils.Func;
import org.springblade.manager.vo.ContractlnfoCountVO;
import org.springframework.util.StringUtils;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.bind.annotation.RequestParam;
import org.springblade.manager.entity.ProjectInfo;
import org.springblade.manager.vo.ProjectInfoVO;
import org.springblade.manager.wrapper.ProjectInfoWrapper;
import org.springblade.manager.service.IProjectInfoService;
import org.springblade.core.boot.ctrl.BladeController;

import java.util.Arrays;
import java.util.List;

/**
 * 客户级项目表 控制器
 *
 * @author liuyc
 * @since 2022-04-13
 */
@RestController
@AllArgsConstructor
@RequestMapping("/projectInfo")
@Api(value = "客户级项目表", tags = "客户级项目表接口")
public class ProjectInfoController extends BladeController {

	private final IProjectInfoService projectInfoService;

	/**
	 * 详情
	 */
	@GetMapping("/detail")
	@ApiOperationSupport(order = 1)
	@ApiOperation(value = "详情", notes = "传入projectInfo")
	public R<ProjectInfoVO> detail(ProjectInfo projectInfo) {
		ProjectInfo detail = projectInfoService.getOne(Condition.getQueryWrapper(projectInfo));
		return R.data(ProjectInfoWrapper.build().entityVO(detail));
	}

	/**
	 * 分页 客户级项目表
	 */
	@GetMapping("/list")
	@ApiOperationSupport(order = 2)
	@ApiOperation(value = "分页", notes = "传入projectInfo")
	public R<IPage<ProjectInfoVO>> list(  ProjectInfo projectInfo, Query query) {

		IPage<ProjectInfo> pages = projectInfoService.page(Condition.getPage(query), Condition.getQueryWrapper(projectInfo));
		pages.getRecords().forEach(System.out::print);

		return R.data(ProjectInfoWrapper.build().pageVO(pages));
	}

	/**
	 * 查询业务条数
	 * @return
	 */
	@GetMapping("/listContractInfoCount")
	@ApiOperationSupport(order = 8)
	@ApiOperation(value = "无参", notes = "null")
	public List<ContractlnfoCountVO> selectContractInfoCount(){
		List<ContractlnfoCountVO> contractlnfoCountsVO = projectInfoService.selectContractInfoCount();
		return contractlnfoCountsVO;
	}


	/**
	 * 自定义分页 客户级项目表
	 */
	@GetMapping("/page")
	@ApiOperationSupport(order = 3)
	@ApiOperation(value = "分页", notes = "传入projectInfo")
	public R<IPage<ProjectInfoVO>> page(ProjectInfoVO projectInfo, Query query) {
		IPage<ProjectInfoVO> pages = projectInfoService.selectProjectInfoPage(Condition.getPage(query), projectInfo);
		return R.data(pages);
	}


	/**
	 * 新增 客户级项目表
	 */
	@PostMapping("/save")
	@ApiOperationSupport(order = 4)
	@ApiOperation(value = "新增", notes = "传入projectInfo")
	public R save(@Valid @RequestBody ProjectInfo projectInfo) {
		return R.status(projectInfoService.save(projectInfo));
	}

	/**
	 * 修改 客户级项目表
	 */
	@PostMapping("/update")
	@ApiOperationSupport(order = 5)
	@ApiOperation(value = "修改", notes = "传入projectInfo")
	public R update(@Valid @RequestBody ProjectInfo projectInfo) {
		return R.status(projectInfoService.updateById(projectInfo));
	}

	/**
	 * 新增或修改 客户级项目表
	 */
	@PostMapping("/submit")
	@ApiOperationSupport(order = 6)
	@ApiOperation(value = "新增或修改", notes = "传入projectInfo")
	public R submit(@Valid @RequestBody ProjectInfo projectInfo) {
		return R.status(projectInfoService.saveOrUpdate(projectInfo));
	}


	/**
	 * 删除 客户级项目表
	 */
	@PostMapping("/remove")
	@ApiOperationSupport(order = 7)
	@ApiOperation(value = "逻辑删除", notes = "传入ids")
	public R remove(@ApiParam(value = "主键集合", required = true) @RequestParam String ids) {
		return R.status(projectInfoService.deleteLogic(Func.toLongList(ids)));
	}


}
