/*
 *      Copyright (c) 2018-2028, Chill Zhuang All rights reserved.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions are met:
 *
 *  Redistributions of source code must retain the above copyright notice,
 *  this list of conditions and the following disclaimer.
 *  Redistributions in binary form must reproduce the above copyright
 *  notice, this list of conditions and the following disclaimer in the
 *  documentation and/or other materials provided with the distribution.
 *  Neither the name of the dreamlu.net developer nor the names of its
 *  contributors may be used to endorse or promote products derived from
 *  this software without specific prior written permission.
 *  Author: Chill 庄骞 (smallchill@163.com)
 */
package org.springblade.manager.controller;

import io.swagger.annotations.*;
import com.github.xiaoymin.knife4j.annotations.ApiOperationSupport;
import lombok.AllArgsConstructor;
import javax.validation.Valid;

import org.springblade.core.tool.api.R;
import org.springblade.core.tool.utils.Func;
import org.springblade.manager.dto.WbsFormElementDTO;
import org.springblade.manager.entity.WbsFormElement;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.bind.annotation.RequestParam;
import org.springblade.manager.service.IWbsFormElementService;
import org.springblade.core.boot.ctrl.BladeController;

/**
 * wbs表单元素 控制器
 *
 * @author liuyc
 * @since 2022-04-27
 */
@RestController
@AllArgsConstructor
@RequestMapping("/wbsFormElement")
@Api(value = "wbs表单元素", tags = "wbs表单元素接口")
public class WbsFormElementController extends BladeController {

	private final IWbsFormElementService wbsFormElementService;

	/**
	 * 新增 wbs表单元素
	 */
	@PostMapping("/save")
	@ApiOperationSupport(order = 1)
	@ApiOperation(value = "新增", notes = "传入wbsFormElement")
	/*@ApiImplicitParams(value = {
		@ApiImplicitParam(name = "fId",value = "父id",required = true),
		@ApiImplicitParam(name = "eName",value = "元素名称",required = true),
		@ApiImplicitParam(name = "eType",value = "元素类型",required = true),
		@ApiImplicitParam(name = "eLength",value = "元素长度",required = true),
		@ApiImplicitParam(name = "eAllowDeviation",value = "允许偏差值",required = true),
		@ApiImplicitParam(name = "eInspectionMethod",value = "检查方法",required = true)
	})*/
	public R save(@Valid @RequestBody WbsFormElementDTO wbsFormElement) {
		return R.status(wbsFormElementService.save(wbsFormElement));
	}


	/**
	 * 修改 wbs表单元素
	 */
	@PostMapping("/update")
	@ApiOperationSupport(order = 2)
	@ApiOperation(value = "修改", notes = "传入wbsFormElement")
	public R update(@Valid @RequestBody WbsFormElement wbsFormElement) {
		return R.status(wbsFormElementService.updateById(wbsFormElement));
	}


	/**
	 * 新增或修改 wbs表单元素
	 */
	@PostMapping("/submit")
	@ApiOperationSupport(order = 3)
	@ApiOperation(value = "新增或修改", notes = "传入wbsFormElement")
	public R submit(@Valid @RequestBody WbsFormElement wbsFormElement) {
		return R.status(wbsFormElementService.saveOrUpdate(wbsFormElement));
	}

	/**
	 * 删除 wbs表单元素
	 */
	@PostMapping("/remove")
	@ApiOperationSupport(order = 4)
	@ApiOperation(value = "逻辑删除", notes = "传入ids")
	public R remove(@ApiParam(value = "主键集合", required = true) @RequestParam String ids) {
		return R.status(wbsFormElementService.deleteLogic(Func.toLongList(ids)));
	}


}
